@@ -90,7 +90,7 @@ if (all(c2)) stop("Use `nmk()' for unconstrained optimization!", call.=FALSE)
     v <- V[, -1] - V[, 1]
     delf <- f[-1] - f[1]
     diam <- sqrt(colSums(v^2))
-    sgrad <- c(crossprod(t(v), delf))
+    sgrad <- c(solve(t(v), delf))
     alpha <- 1e-04 * max(diam)/sqrt(sum(sgrad^2))
     simplex.size <- sum(abs(V[, -1] - V[, 1]))/max(1, sum(abs(V[, 
         1])))
